@@ -26,17 +26,22 @@ __all__ = [
     # multimodal
     "image",
     "audio",
-    "transcribe"
+    "transcribe",
+
+    # Memory (xnano[data])
+    "Store",
 ]
 
 
+from pydantic import Field
+
+
 from .main import (
     Completions,
     completion,
     InstructorMode,
-    PredefinedModel,
     BaseModel,
-    Field
+    PredefinedModel,
 )
 
 
@@ -58,3 +63,6 @@ from .lib import (
     transcribe,
     query,
 )
+
+
+from .stores import Store
