@@ -3,7 +3,7 @@ from pydantic import BaseModel, Field
 from loguru import logger
 from rich.progress import Progress, SpinnerColumn, TextColumn
 
-from ..import Completions, InstructorMode
+from .. import Completions, InstructorMode, PredefinedModel
 
 
 class JudgmentResult(BaseModel):
@@ -37,7 +37,7 @@ def validator(
     process: Literal["accuracy", "validate", "fact_check", "guardrails"] = "accuracy",
     schema: Optional[Union[str, dict]] = None,
     regenerate: bool = False,
-    model: str = "gpt-4o-mini",
+    model: Union[str, PredefinedModel] = "gpt-4o-mini",
     api_key: Optional[str] = None,
     base_url: Optional[str] = None,
     temperature: float = 0.7,
