@@ -2,24 +2,12 @@
 # primary module for xnano
 # entrypoint for completions
 
-__all__ = [
-    "Completions",
-    "completion",
-    "InstructorMode",
-
-    "BaseModel",
-    "Field"
-]
-
 # xnano/main.py
 # hammad saeed .. twentytwentyfour
 
 # base module for llm client
 # litellm extension included in xnano[ext] or xnano[all]
 
-# internal
-from .utils.convert_to_openai_tool import convert_to_openai_tool
-
 # ext
 import enum
 import time
@@ -41,6 +29,7 @@ from typing import (
     Union
 )
 import json
+from rich.console import Console
 from rich.progress import Progress, SpinnerColumn, TimeElapsedColumn, TextColumn
 
 
@@ -209,6 +198,8 @@ class Completions:
     @staticmethod
     def format_to_openai_tools(tools: List[Union[Dict[str, Any], Type[PydanticBaseModel], Callable]]) -> List[Dict[str, Any]]:
         """Converts the tools to a list of OpenAI-compatible tool dictionaries."""
+        from .utils.convert_to_openai_tool import convert_to_openai_tool
+
         formatted_tools = []
         for tool in tools:
             logger.info(f"Processing tool: {tool}, type: {type(tool)}")
@@ -405,7 +396,7 @@ class Completions:
 
     def __init_openai_client__(self):
         from openai import OpenAI
-        
+
         return OpenAI(
             api_key=self.config.api_key,
             base_url=self.config.base_url,
@@ -535,7 +526,7 @@ class Completions:
             **kwargs
     ):
         """Generate an LLM Completion with tools, streaming or Pydantic structured outputs.
-        
+
         Example:
     `        ```python
             response = completion(
@@ -696,11 +687,12 @@ def completion(
         stream : Optional[bool] = None,
         provider : Optional[Literal["openai", "litellm"]] = "openai",
         progress_bar : Optional[bool] = True,
+        chat : Optional[bool] = False,
         verbose : Optional[bool] = False,
         **kwargs
 ) -> Any:
     """Runs an LLM completion, with tools, streaming or Pydantic structured outputs.
-    
+
     Example:
         ```python
         response = completion(
@@ -756,6 +748,53 @@ def completion(
     if stream:
         progress_bar = False
 
+    if chat:
+        stream = True
+
+        from rich.console import Console
+
+        console = Console()
+
+        thread = Completions.format_messages(messages)
+
+        while True:
+            user_input = console.input("\nUser: ")
+
+            # Check for exit command
+            if user_input.lower() in ["exit", "quit", "bye"]:
+                console.print("\nGoodbye!")
+                break
+
+            thread.append({"role": "user", "content": user_input})
+
+            response = client.completion(
+                messages=thread,
+                model=model,
+                image=image,
+                response_model=response_model,
+                mode=mode,
+                max_retries=max_retries,
+                run_tools=run_tools,
+                tools=tools,
+                parallel_tool_calls=parallel_tool_calls,
+                tool_choice=tool_choice,
+                max_tokens=max_tokens,
+                temperature=temperature,
+                top_p=top_p,
+                frequency_penalty=frequency_penalty,
+                presence_penalty=presence_penalty,
+                stop=stop,
+                progress_bar=progress_bar,
+                stream=stream,
+                **kwargs
+            )
+
+            thread.append({"role": "assistant", "content": str(response)})
+
+            print("\nAssistant:")
+            for chunk in response:
+                print(f"{chunk.choices[0].delta.content}", end="")
+
     if progress_bar:
         with Progress(
             SpinnerColumn(),
@@ -812,7 +851,8 @@ def completion(
                 stream=stream,
                 **kwargs
             )
-    
+
+
 
 # Pydantic BaseModel Subclass Client
 class BaseModel(PydanticBaseModel):
@@ -875,7 +915,7 @@ class BaseModel(PydanticBaseModel):
         progress_bar: Optional[bool] = True,
     ) -> Union[T, List[T]]:
         """Generates instance(s) of the given Pydantic model.
-        
+
         Example:
             ```python
             class PersonModel(PydanticBaseModel):
@@ -943,7 +983,7 @@ class BaseModel(PydanticBaseModel):
                     transient=True
                 ) as progress:
                     task_id = progress.add_task("Generating Model(s)...", total=None)
-                    
+
                     response = completion_client.completion(
                         messages=[
                             {"role": "system", "content": system_message},
@@ -1068,7 +1108,7 @@ class BaseModel(PydanticBaseModel):
                     results.append(cls(**instance))
 
             return results[0] if n == 1 else results
-        
+
 
     @classmethod
     def select(
@@ -1088,7 +1128,7 @@ class BaseModel(PydanticBaseModel):
         verbose: bool = False,
     ) -> Union[enum.Enum, List[enum.Enum]]:
         """Selects values for an Enum field.
-        
+
         Example:
             ```python
             class PersonModel(PydanticBaseModel):
@@ -1098,7 +1138,7 @@ class BaseModel(PydanticBaseModel):
 
             PersonModel.select(field_name="secret_identity", instructions="Select a secret identity for the person.")
             ```
-        
+
         Args:
             cls (Type[T]): The class of the Pydantic model.
             field_name (str): The name of the Enum field to select values for.
@@ -1209,11 +1249,12 @@ class BaseModel(PydanticBaseModel):
                 for selection, explanation in zip(results, response.explanations):
                     logger.info(f"Selected: {selection}")
                     logger.info(f"Explanation: {explanation}")
-            
+
 
         return results[0] if n == 1 else results
 
 
+
 if __name__ == "__main__":
     class PersonModel(PydanticBaseModel):
         secret_identity: str
